<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet	version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
				xmlns:msxsl="urn:schemas-microsoft-com:xslt">
	<!--
	=============================================================================================
	-->
	<xsl:variable name="wersja" select="'1.0'"/>
	<xsl:variable name="liczba" select="'##&#160;###&#160;##0'"/>
	<xsl:decimal-format grouping-separator="&#160;"/>
	<xsl:variable name="width" select="600"/>
	<!--
	=============================================================================================
	-->
	<xsl:template match="/">
		<html>
			<head>
				<style type="text/css">
					th					{color: #000000; font-family: Tahoma, Verdana; font-size: 11px;
                                 		font-weight: bold;
                                		}

					.col_first		{width:  <xsl:value-of select="$width - 2 * 100"/>px}
					.col_next		{width:  100px}

					.tab_col		{text-align: center; vertical-align: middle;
										color: #000000; font-family: Tahoma, Verdana; font-size: 9px;
										font-weight: normal;
										}

					.tab_row		{padding-left: 3px; text-align: center; vertical-align: middle;
										color: #000000; font-family: Tahoma, Verdana; font-size: 9px;
										font-weight: normal;
										}

					.contents		{height: 2.0em; padding-right: 2px; text-align: right;
										vertical-align: middle; color: #000000; font-family: Tahoma,
										Verdana; font-size: 11px; font-weight: bold;
										}

					.totals			{height: 2.0em; padding-right: 2px;
										text-align: right; vertical-align: middle;
										background-color: silver; font-family: Tahoma, Verdana;
										font-size: 11px; font-weight: bold;
										}

					.row_descr	{padding-left: 5px; text-align: left; vertical-align: middle;
										color: #000000; font-family: Tahoma, Verdana; font-size: 11px;
										font-weight: normal;
										}

					.xslt_ver		{font-family: Tahoma, Verdana; font-size: 12px;
										font-weight: bold; margin-top: 14px;
										}

					.wide			{width: <xsl:value-of select="$width"/>px; padding-top: 14px;
										}
				</style>
			</head>
			<body>
				<xsl:apply-templates select="Raport"/>
			</body>
		</html>
	</xsl:template>
	<!--
	=============================================================================================
	-->
	<xsl:template match="Raport">
		<xsl:apply-templates select="Wydawnictwa"/>
		<xsl:call-template name="Stopka"/>
	</xsl:template>
	<!--
	=============================================================================================
	-->
	<xsl:template name="Stopka">
		<table class="wide" border="0" cellspacing="0" cellpadding="0">
			<tr>
				<td class="xslt_ver" style="text-align: left;">
					Wersja szablonu XSLT: <xsl:value-of select="$wersja"/>
				</td>
				<td class="xslt_ver" style="text-align: right;">
					<xsl:value-of select="concat('XSLT wersja ', system-property('xsl:version'), ', producent: ', system-property('xsl:vendor'))"/>
					<xsl:if test="system-property('msxsl:version')">
						<xsl:value-of select="concat(', MSXML: ', system-property('msxsl:version'))"/>
					</xsl:if>
				</td>
			</tr>
		</table>
	</xsl:template>
	<!--
	=============================================================================================
	-->
	<xsl:template name="Row-description">
		<xsl:param name="level"/><xsl:param name="item"/>
		<xsl:variable name="topbot" select="'margin-top: 4px; margin-bottom: 4px; margin-left: '"/>
		<xsl:variable name="indent" select="25"/>
		<td class="row_descr">
			<xsl:if test="not(preceding-sibling::*) and ../@Prefiks">
				<p>
					<xsl:attribute name="style">
						<xsl:value-of select="concat($topbot, string($indent * ($level -1)), 'px;')" />
					</xsl:attribute>
					<xsl:value-of select="../@Prefiks"/><br/>
				</p>
			</xsl:if>
			<p>
				<xsl:if test="$level &gt;= 0">
					<xsl:attribute name="style">
						<xsl:value-of select="concat($topbot, string($indent * $level), 'px;')" />
						<xsl:if test="@Kategoria">
							<xsl:value-of select="'font-weight: bold;'"/>
						</xsl:if>
					</xsl:attribute>
				</xsl:if>
				<xsl:value-of select="@Kategoria"/>
				<xsl:value-of select="@Tytuł"/>
			</p>
		</td>
		<td class="tab_row">
			<xsl:value-of select="count(preceding::*[name() = $item])+
								  count(ancestor-or-self::*[name() = $item])"/>
		</td>
	</xsl:template>
	<!--
	=============================================================================================
	-->
	<xsl:template match="Wydawnictwa">
		<div>
 			<xsl:attribute name="style">
 				page-break-before: always;
 				font-size: medium; font-weight: bold; margin-bottom: 0.4em;
 				width: <xsl:number value="$width" />px
			</xsl:attribute>
			<xsl:value-of select="concat(name(.), ': ', @Opis)"/>
		</div>
		<table border="2" cellspacing="0" cellpadding="0">
 			<xsl:attribute name="width">
 				<xsl:number value="$width"/>
			</xsl:attribute>
			<thead>
				<tr>
					<th class="col_first" colspan="2">Tytuł lub kategoria</th>
					<th class="col_next">Nakład w&#160;tysiącach</th>
					<th class="col_next">Liczba zwrotów w&#160;tysiącach</th>
				</tr>
				<tr>
					<td class="tab_col" colspan="2">0</td>
					<td class="tab_col">1</td>
					<td class="tab_col">2</td>
				</tr>
			</thead>
			<tbody>
				<xsl:apply-templates select="Tytuł-lub-kategoria">
					<xsl:with-param name="margin" select="0"/>
				</xsl:apply-templates>
			</tbody>
		</table>
	</xsl:template>
	<!--
	- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	-->
	<xsl:template match="Tytuł-lub-kategoria">
		<xsl:param name="subtree" select="'Statystyka'"/>
		<xsl:param name="margin"/>
		<tr>
			<xsl:call-template name="Row-description">
				<xsl:with-param name="level" select="$margin"/>
				<xsl:with-param name="item" select="name(.)"/>
			</xsl:call-template>

			<xsl:call-template name="_column">
				<xsl:with-param name="subtree" select="$subtree"/>
				<xsl:with-param name="column" select="'Nakład-ogółem'"/>
				<xsl:with-param name="format" select="$liczba"/>
			</xsl:call-template>
			<xsl:call-template name="_column">
				<xsl:with-param name="subtree" select="$subtree"/>
				<xsl:with-param name="column" select="'Liczba-zwrotów'"/>
				<xsl:with-param name="format" select="$liczba"/>
			</xsl:call-template>
		</tr>

		<xsl:apply-templates select="*/Tytuł-lub-kategoria">
			<xsl:with-param name="margin" select="$margin + 1"/>
		</xsl:apply-templates>
	</xsl:template>
	<!--
	- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	-->
	<xsl:template name="_column">
		<xsl:param name="subtree"/> <xsl:param name="column"/> <xsl:param name="format"/>
		<xsl:param name="item" select="*[name(.) = $subtree]/*[name(.) = $column]"/>
		<xsl:param name="contents">
			<xsl:value-of select="$item"/>
		</xsl:param>
		<td class="contents">
 			<xsl:value-of select="format-number($contents, $format)"/>
		</td>
	</xsl:template>
	<!--
	=============================================================================================
	-->
</xsl:stylesheet>
